@@ -3,7 +3,7 @@ use warnings;
 
 package Oh;
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 use subs qw/error env listp evaluate_element evaluate_list evaluate_function evaluate_builtin evaluate_macro evaluate_lambda find search progn read_element read_string read_list reft/;
 
@@ -713,7 +713,7 @@ sub lisp_args
     {
       $state = 'optional';
     }
-    elsif ($arg eq '&keyword')
+    elsif ($arg eq '&key')
     {
       $state = 'keyword';
     }
